@@ -39,7 +39,7 @@ namespace snmalloc
     {
       if (page_aligned || is_aligned_block<OS_PAGE_SIZE>(p, size))
       {
-        assert(is_aligned_block<OS_PAGE_SIZE>(p, size));
+        SNMALLOC_ASSERT(is_aligned_block<OS_PAGE_SIZE>(p, size));
         madvise(p, size, MADV_DONTNEED);
       }
       else
